@@ -278,7 +278,7 @@ typedef struct _revdir {
  * described a gitspace commit potentially pointing at several files.  The
  * first semantics held for instances created while scanning CVS master files;
  * the second for those generated by a git_commit_build() call during 
- * global branch merging.
+ * global branch collation.
  *
  * The problem with this is that some members in the late interpretation 
  * are unused in the earlier one; we want to get rid of as many as possible to 
@@ -432,7 +432,8 @@ typedef struct _cvs_author {
 #define _alignof(T)  sizeof(long double)
 #endif
 
-#if defined(__APPLE__)
+/* For versions of Mac OS X before Sierra */
+#if defined(__APPLE__) && !defined(CLOCK_REALTIME)
 /* we mock this in utils.c; the CLOCK_REALTIME value is not used */
 typedef int clockid_t;
 int clock_gettime(clockid_t clock_id, struct timespec *tp);
@@ -459,7 +460,7 @@ cvs_commit *
 cvs_master_digest(cvs_file *cvs, cvs_master *cm, rev_master *master);
 
 git_repo *
-merge_to_changesets(cvs_master *masters, size_t nmasters, int verbose);
+collate_to_changesets(cvs_master *masters, size_t nmasters, int verbose);
 
 enum { Ncommits = 256 };
 
